@@ -42,6 +42,7 @@ timer_handler(gpointer data) {
     struct event_time *evt;
     time_t current_time;
     int check;
+    gchar buffer[2048];
 #ifdef DEBUGEVENTS
     char *temp_string;
 #endif
@@ -119,6 +120,13 @@ timer_handler(gpointer data) {
                                                     app->temporary_station_latitude,app->temporary_station_longtitude));
 
 */
+                sprintf(buffer,"Event:  Calculate CHECK_GPS_POSITION %f %f %f %f %f\n",
+                                    app->gps_station.latitude,app->gps_station.longtitude,
+                                    app->temporary_station_latitude,app->temporary_station_longtitude,
+                                    calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
+                                                    app->temporary_station_latitude,app->temporary_station_longtitude));
+                write_log(buffer);
+                write_log(app->gps_station.name);
                 if (calculate_distance
                     (app->gps_station.latitude,
                      app->gps_station.longtitude,
@@ -149,13 +157,11 @@ timer_handler(gpointer data) {
                             /* Fix me if source are not weather.com */
                             if (app->config->current_station_name)
                                 g_free(app->config->current_station_name);
-                            app->config->current_station_name =
-                                g_strdup(app->gps_station.name);
+                            app->config->current_station_name = g_strdup(app->gps_station.name);
 
                             if (app->config->current_station_id)
                                 g_free(app->config->current_station_id);
-                            app->config->current_station_id =
-                                g_strdup(app->gps_station.id0);
+                            app->config->current_station_id = g_strdup(app->gps_station.id0);
                         }
                         config_save(app->config);
                         update_weather(FALSE);
@@ -322,9 +328,9 @@ void event_add(time_t time_value, short type_event) {
 /*  Addition the periodic time in the list of events  for weather forecast updating.  
     Interval is a count of minutes for the next interval */
 void add_gps_event(guint interval) {
-#ifdef DEBUGFUNCTIONCALL
+//#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-#endif
+//#endif
 #ifdef DEBUGEVENTS
     fprintf(stderr, "Add in list\n");
     print_list(NULL, 0);
