@@ -37,9 +37,9 @@
 void
 get_nearest_station(double lat, double lon, Station *result) {
 
-#ifdef DEBUGFUNCTIONCALL
+//#ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
-#endif
+//#endif
     Region_item region;
     GtkListStore *stations_list = NULL;
     GtkListStore *regions_list = NULL;
@@ -146,9 +146,9 @@ get_nearest_station(double lat, double lon, Station *result) {
                                      (regions_list), &iter_region);
     }
     close_database(database);
-#ifdef DEBUGFUNCTIONCALL
+//#ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
-#endif
+//#endif
 }
 /*******************************************************************************/ 
 static void 
